===========
Computation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Series.abs
    Series.arccos
    Series.arccosh
    Series.arcsin
    Series.arcsinh
    Series.arctan
    Series.arctanh
    Series.arg_true
    Series.arg_unique
    Series.approx_n_unique
    Series.bitwise_count_ones
    Series.bitwise_count_zeros
    Series.bitwise_leading_ones
    Series.bitwise_leading_zeros
    Series.bitwise_trailing_ones
    Series.bitwise_trailing_zeros
    Series.bitwise_and
    Series.bitwise_or
    Series.bitwise_xor
    Series.cbrt
    Series.cos
    Series.cosh
    Series.cot
    Series.cum_count
    Series.cum_max
    Series.cum_min
    Series.cum_prod
    Series.cum_sum
    Series.cumulative_eval
    Series.diff
    Series.dot
    Series.entropy
    Series.ewm_mean
    Series.ewm_mean_by
    Series.ewm_std
    Series.ewm_var
    Series.exp
    Series.first
    Series.hash
    Series.hist
    Series.index_of
    Series.is_between
    Series.is_close
    Series.kurtosis
    Series.last
    Series.log
    Series.log10
    Series.log1p
    Series.pct_change
    Series.peak_max
    Series.peak_min
    Series.rank
    Series.replace
    Series.replace_strict
    Series.rolling_kurtosis
    Series.rolling_map
    Series.rolling_max
    Series.rolling_mean
    Series.rolling_median
    Series.rolling_min
    Series.rolling_quantile
    Series.rolling_skew
    Series.rolling_std
    Series.rolling_sum
    Series.rolling_var
    Series.search_sorted
    Series.sign
    Series.sin
    Series.sinh
    Series.skew
    Series.sqrt
    Series.tan
    Series.tanh
